@@ -1,4 +1,5 @@
 #include <stdio.h>
+#include <string.h>
 #include <unistd.h>
 #include "eps.h"
 
@@ -8,6 +9,9 @@ void base64_init(base64_t *b)
 {
   int i = 0;
 
+  memset(b->inalphabet, 0, sizeof(b->inalphabet));
+  memset(b->decoder, 0, sizeof(b->decoder));
+
   for (i = (sizeof alphabet) - 1; i >= 0 ; i--) {
       b->inalphabet[alphabet[i]] = 1;
       b->decoder[alphabet[i]] = i;
