@@ -16,7 +16,7 @@ struct _content_t encoding_prefs[] = {
   { "base64", ENC_BASE64 },
   { "8bit", ENC_8BIT },
   { "quoted-printable", ENC_QP },
-  { "raw", ENC_RAW },
+  { "binary", ENC_BINARY },
   { NULL, ENC_UNKNOWN }
 };
 
