@@ -1,3 +1,6 @@
+#ifndef __CONTENT_H_
+ #define __CONTENT_H_
+
 #define TYP_CON 0
 #define TYP_ENC 1
 #define TYP_DIS 2
@@ -23,7 +26,7 @@
 #define ENC_7BIT     4 /* 7bit             */
 #define ENC_8BIT     8 /* 8bit             */
 #define ENC_QP      16 /* quoted/printable */
-#define ENC_RAW     32 /* raw              */
+#define ENC_BINARY  32 /* binary           */
 #define ENC_UNSPEC  64 /* unspecified      */
 #define ENC_UNKNOWN ENC_NONE
 
@@ -44,3 +47,4 @@ struct _content_t {
 
 int content_parse(char *, char);
 
+#endif
