@@ -3,15 +3,17 @@
 #include <string.h>
 #include "eps.h"
 
+static void email_content_type(eps_t *, header_t *, void *);
+
 struct i_header_t _i_headers[] = {
   { "Content-type", email_content_type },
   { NULL, NULL }
 };
 
-void email_content_type(struct eps_t *eps, struct header_t *h, void *x)
+void email_content_type(eps_t *eps, header_t *h, void *x)
 {
-  int type = 0;
   char *p = NULL;
+  int type = 0, len = 0;
 
   if ((!eps->h) || (!eps->h->atoms) || (!eps->h->atoms->next) ||
       (!eps->h->atoms->next->data)) {
@@ -21,6 +23,17 @@ void email_content_type(struct eps_t *eps, struct header_t *h, void *x)
   }
 
   else {
+    if (eps->h_content_type)
+       free(eps->h_content_type);
+
+    len = strlen(eps->h->atoms->next->data);
+
+    eps->h_content_type = (char *)malloc(len + 1);
+    if (eps->h_content_type) {
+       memset(eps->h_content_type, 0, len + 1);
+       memcpy(eps->h_content_type, eps->h->atoms->next->data, len);
+    }
+
     type = content_parse(eps->h->atoms->next->data, TYP_CON);
     eps->content_type = type;
   }
@@ -41,7 +54,7 @@ void email_content_type(struct eps_t *eps, struct header_t *h, void *x)
   }  
 }
 
-void email_header_internal(struct eps_t *eps)
+void email_header_internal(eps_t *eps)
 {
   int i = 0;
 
