@@ -1,3 +1,6 @@
+#ifndef __INTERFACE_H_
+ #define __INTERFACE_H_
+
 /*
    Interface flags
 */
@@ -6,3 +9,6 @@
 #define INTERFACE_STREAM                         1 /* Stream       */
 #define INTERFACE_BUFFER                         2 /* Buffer       */
 #define INTERFACE_BUFFER_PEICE                   4 /* Peice buffer */
+#define INTERFACE_ASYNC							 8 /* Asynchronous */
+
+#endif
